==> knative-model-4.9.2-sources.jar: io/fabric8/knative/flows/v1alpha1/SequenceSpecFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpec;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.dev.messaging.v1beta1.ChannelTemplateSpecFluent;
import io.fabric8.knative.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SequenceSpecFluent<A extends SequenceSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplate instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ChannelTemplateSpec getChannelTemplate();
    public ChannelTemplateSpec buildChannelTemplate();
    public A withChannelTemplate(ChannelTemplateSpec channelTemplate);
    public Boolean hasChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplateLike(ChannelTemplateSpec item);
    public SequenceSpecFluent.ChannelTemplateNested<A> editChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplateLike(ChannelTemplateSpec item);
    
/**
 * This method has been deprecated, please use method buildReply instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public Destination getReply();
    public Destination buildReply();
    public A withReply(Destination reply);
    public Boolean hasReply();
    public SequenceSpecFluent.ReplyNested<A> withNewReply();
    public SequenceSpecFluent.ReplyNested<A> withNewReplyLike(Destination item);
    public SequenceSpecFluent.ReplyNested<A> editReply();
    public SequenceSpecFluent.ReplyNested<A> editOrNewReply();
    public SequenceSpecFluent.ReplyNested<A> editOrNewReplyLike(Destination item);
    public A addToSteps(int index,SequenceStep item);
    public A setToSteps(int index,SequenceStep item);
    public A addToSteps(SequenceStep... items);
    public A addAllToSteps(Collection<SequenceStep> items);
    public A removeFromSteps(SequenceStep... items);
    public A removeAllFromSteps(Collection<SequenceStep> items);
    public A removeMatchingFromSteps(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSteps instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<SequenceStep> getSteps();
    public List<SequenceStep> buildSteps();
    public SequenceStep buildStep(int index);
    public SequenceStep buildFirstStep();
    public SequenceStep buildLastStep();
    public SequenceStep buildMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    public Boolean hasMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    public A withSteps(List<SequenceStep> steps);
    public A withSteps(SequenceStep... steps);
    public Boolean hasSteps();
    public SequenceSpecFluent.StepsNested<A> addNewStep();
    public SequenceSpecFluent.StepsNested<A> addNewStepLike(SequenceStep item);
    public SequenceSpecFluent.StepsNested<A> setNewStepLike(int index,SequenceStep item);
    public SequenceSpecFluent.StepsNested<A> editStep(int index);
    public SequenceSpecFluent.StepsNested<A> editFirstStep();
    public SequenceSpecFluent.StepsNested<A> editLastStep();
    public SequenceSpecFluent.StepsNested<A> editMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);

    public interface ChannelTemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ChannelTemplateSpecFluent<SequenceSpecFluent.ChannelTemplateNested<N>>{

        
    public N and();    public N endChannelTemplate();
}
    public interface ReplyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<SequenceSpecFluent.ReplyNested<N>>{

        
    public N and();    public N endReply();
}
    public interface StepsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceStepFluent<SequenceSpecFluent.StepsNested<N>>{

        
    public N and();    public N endStep();
}


}

==> knative-model-4.11.0-sources.jar: io/fabric8/knative/flows/v1alpha1/SequenceSpecFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpec;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpecBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.messaging.v1beta1.ChannelTemplateSpecFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SequenceSpecFluent<A extends SequenceSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildChannelTemplate instead.
 * @return The buildable object.
 */
@Deprecated public ChannelTemplateSpec getChannelTemplate();
    public ChannelTemplateSpec buildChannelTemplate();
    public A withChannelTemplate(ChannelTemplateSpec channelTemplate);
    public Boolean hasChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> withNewChannelTemplateLike(ChannelTemplateSpec item);
    public SequenceSpecFluent.ChannelTemplateNested<A> editChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplate();
    public SequenceSpecFluent.ChannelTemplateNested<A> editOrNewChannelTemplateLike(ChannelTemplateSpec item);
    
/**
 * This method has been deprecated, please use method buildReply instead.
 * @return The buildable object.
 */
@Deprecated public Destination getReply();
    public Destination buildReply();
    public A withReply(Destination reply);
    public Boolean hasReply();
    public SequenceSpecFluent.ReplyNested<A> withNewReply();
    public SequenceSpecFluent.ReplyNested<A> withNewReplyLike(Destination item);
    public SequenceSpecFluent.ReplyNested<A> editReply();
    public SequenceSpecFluent.ReplyNested<A> editOrNewReply();
    public SequenceSpecFluent.ReplyNested<A> editOrNewReplyLike(Destination item);
    public A addToSteps(int index,SequenceStep item);
    public A setToSteps(int index,SequenceStep item);
    public A addToSteps(SequenceStep... items);
    public A addAllToSteps(Collection<SequenceStep> items);
    public A removeFromSteps(SequenceStep... items);
    public A removeAllFromSteps(Collection<SequenceStep> items);
    public A removeMatchingFromSteps(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSteps instead.
 * @return The buildable object.
 */
@Deprecated public List<SequenceStep> getSteps();
    public List<SequenceStep> buildSteps();
    public SequenceStep buildStep(int index);
    public SequenceStep buildFirstStep();
    public SequenceStep buildLastStep();
    public SequenceStep buildMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    public Boolean hasMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);
    public A withSteps(List<SequenceStep> steps);
    public A withSteps(SequenceStep... steps);
    public Boolean hasSteps();
    public SequenceSpecFluent.StepsNested<A> addNewStep();
    public SequenceSpecFluent.StepsNested<A> addNewStepLike(SequenceStep item);
    public SequenceSpecFluent.StepsNested<A> setNewStepLike(int index,SequenceStep item);
    public SequenceSpecFluent.StepsNested<A> editStep(int index);
    public SequenceSpecFluent.StepsNested<A> editFirstStep();
    public SequenceSpecFluent.StepsNested<A> editLastStep();
    public SequenceSpecFluent.StepsNested<A> editMatchingStep(io.fabric8.kubernetes.api.builder.Predicate<SequenceStepBuilder> predicate);

    public interface ChannelTemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ChannelTemplateSpecFluent<SequenceSpecFluent.ChannelTemplateNested<N>>{

        
    public N and();    public N endChannelTemplate();
}
    public interface ReplyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<SequenceSpecFluent.ReplyNested<N>>{

        
    public N and();    public N endReply();
}
    public interface StepsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceStepFluent<SequenceSpecFluent.StepsNested<N>>{

        
    public N and();    public N endStep();
}


}
